@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -32,10 +32,15 @@ sub _init {
 }
 
 sub gzip {
-    my ($self) = @_;
-    my $gzipped = Compress::Zlib::memGzip( $self->string() )
+    my ( $self, $gzipped ) = @_;
+    my $old = Compress::Zlib::memGzip( $self->string() )
       or Carp::croak('Failed to gzip HAR archive');
-    return $gzipped;
+    if ( defined $gzipped ) {
+        my $string = Compress::Zlib::memGunzip($gzipped)
+          or Carp::croak('Failed to gunzip HAR archive');
+        $self->string($string);
+    }
+    return $old;
 }
 
 sub hashref {
@@ -471,9 +476,9 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
-=for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref
+=for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref gunzipping
 
 =head1 SYNOPSIS
 
@@ -514,7 +519,7 @@ $har->hashref() accepts a hashref of the L<HTTP archive|http://www.softwareishar
 
 =head2 gzip
 
-$har->gzip() returns a gzipped copy of the current state of the archive in stringified form
+$har->gzip() accepts a gzipped version of an L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it. It returns a gzipped version of the previous state of the archive
 
 =head2 xml
 
@@ -552,6 +557,10 @@ $har->comment() will return the comment for the HTTP Archive
 
 An error occurred while gzipping.
 
+=item C<< Failed to gunzip HAR archive >>
+
+An error occurred while gunzipping.
+
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
